==> jc-1.4.0.tar.gz: javax/transaction/xa/XAException.h <==
// public class javax.transaction.xa.XAException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c9e46dc9e1e9d87b javax_transaction_xa_XAException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_javax_transaction_xa_XAException_H_
#define _JC_javax_transaction_xa_XAException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_transaction_xa_XAException$sub_refs	_jc_javax_transaction_xa_XAException$sub_refs;
typedef struct _jc_javax_transaction_xa_XAException$sub_nonrefs	_jc_javax_transaction_xa_XAException$sub_nonrefs;
typedef struct _jc_javax_transaction_xa_XAException$refs	_jc_javax_transaction_xa_XAException$refs;
typedef struct _jc_javax_transaction_xa_XAException$nonrefs	_jc_javax_transaction_xa_XAException$nonrefs;
typedef struct _jc_javax_transaction_xa_XAException$object	_jc_javax_transaction_xa_XAException$object;

typedef struct _jc_javax_transaction_xa_XAException$fields_struct	_jc_javax_transaction_xa_XAException$fields_struct;
typedef const struct _jc_javax_transaction_xa_XAException$vmethods	_jc_javax_transaction_xa_XAException$vmethods;
typedef const struct _jc_javax_transaction_xa_XAException$vtable	_jc_javax_transaction_xa_XAException$vtable;
typedef const struct _jc_javax_transaction_xa_XAException$vtype	_jc_javax_transaction_xa_XAException$vtype;

// Class fields structure
struct _jc_javax_transaction_xa_XAException$fields_struct {
	jint	XAER__5fASYNC;
	jint	XAER__5fDUPID;
	jint	XAER__5fINVAL;
	jint	XAER__5fNOTA;
	jint	XAER__5fOUTSIDE;
	jint	XAER__5fPROTO;
	jint	XAER__5fRMERR;
	jint	XAER__5fRMFAIL;
	jint	XA__5fHEURCOM;
	jint	XA__5fHEURHAZ;
	jint	XA__5fHEURMIX;
	jint	XA__5fHEURRB;
	jint	XA__5fNOMIGRATE;
	jint	XA__5fRBBASE;
	jint	XA__5fRBCOMMFAIL;
	jint	XA__5fRBDEADLOCK;
	jint	XA__5fRBEND;
	jint	XA__5fRBINTEGRITY;
	jint	XA__5fRBOTHER;
	jint	XA__5fRBPROTO;
	jint	XA__5fRBROLLBACK;
	jint	XA__5fRBTIMEOUT;
	jint	XA__5fRBTRANSIENT;
	jint	XA__5fRDONLY;
	jint	XA__5fRETRY;
};
extern _jc_javax_transaction_xa_XAException$fields_struct _jc_javax_transaction_xa_XAException$class_fields;

// Constructors
extern void _jc_javax_transaction_xa_XAException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_transaction_xa_XAException$object *);
extern void _jc_javax_transaction_xa_XAException$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_transaction_xa_XAException$object *, jint);
extern void _jc_javax_transaction_xa_XAException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_transaction_xa_XAException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_javax_transaction_xa_XAException$vmethods {
};

// Vtable
struct _jc_javax_transaction_xa_XAException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_transaction_xa_XAException$vmethods	javax_transaction_xa_XAException;
};

// Vtype
struct _jc_javax_transaction_xa_XAException$vtype {
	_jc_type			type;
	_jc_javax_transaction_xa_XAException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_transaction_xa_XAException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_transaction_xa_XAException$refs {
    _jc_javax_transaction_xa_XAException$sub_refs	javax_transaction_xa_XAException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_transaction_xa_XAException$sub_nonrefs {
	jint	errorCode;
};

// Non-reference instance fields (object)
struct _jc_javax_transaction_xa_XAException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_transaction_xa_XAException$sub_nonrefs	javax_transaction_xa_XAException;
};

// Object instance structure
struct _jc_javax_transaction_xa_XAException$object {
	_jc_javax_transaction_xa_XAException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_transaction_xa_XAException$vtype	*vtype;
	_jc_javax_transaction_xa_XAException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_transaction_xa_XAException$vtype _jc_javax_transaction_xa_XAException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_transaction_xa_XAException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_transaction_xa_XAException$class_object;

#endif	/* _JC_javax_transaction_xa_XAException_H_ */

==> jc-1.4.6.tar.gz: javax/transaction/xa/XAException.h <==
// public class javax.transaction.xa.XAException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c9e46dc9e1e9d87b javax_transaction_xa_XAException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_javax_transaction_xa_XAException_H_
#define _JC_javax_transaction_xa_XAException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_transaction_xa_XAException$sub_refs	_jc_javax_transaction_xa_XAException$sub_refs;
typedef struct _jc_javax_transaction_xa_XAException$sub_nonrefs	_jc_javax_transaction_xa_XAException$sub_nonrefs;
typedef struct _jc_javax_transaction_xa_XAException$refs	_jc_javax_transaction_xa_XAException$refs;
typedef struct _jc_javax_transaction_xa_XAException$nonrefs	_jc_javax_transaction_xa_XAException$nonrefs;
typedef struct _jc_javax_transaction_xa_XAException$object	_jc_javax_transaction_xa_XAException$object;

typedef struct _jc_javax_transaction_xa_XAException$fields_struct	_jc_javax_transaction_xa_XAException$fields_struct;
typedef const struct _jc_javax_transaction_xa_XAException$vmethods	_jc_javax_transaction_xa_XAException$vmethods;
typedef const struct _jc_javax_transaction_xa_XAException$vtable	_jc_javax_transaction_xa_XAException$vtable;
typedef const struct _jc_javax_transaction_xa_XAException$vtype	_jc_javax_transaction_xa_XAException$vtype;

// Class fields structure
struct _jc_javax_transaction_xa_XAException$fields_struct {
	jint	XAER__5fASYNC;
	jint	XAER__5fDUPID;
	jint	XAER__5fINVAL;
	jint	XAER__5fNOTA;
	jint	XAER__5fOUTSIDE;
	jint	XAER__5fPROTO;
	jint	XAER__5fRMERR;
	jint	XAER__5fRMFAIL;
	jint	XA__5fHEURCOM;
	jint	XA__5fHEURHAZ;
	jint	XA__5fHEURMIX;
	jint	XA__5fHEURRB;
	jint	XA__5fNOMIGRATE;
	jint	XA__5fRBBASE;
	jint	XA__5fRBCOMMFAIL;
	jint	XA__5fRBDEADLOCK;
	jint	XA__5fRBEND;
	jint	XA__5fRBINTEGRITY;
	jint	XA__5fRBOTHER;
	jint	XA__5fRBPROTO;
	jint	XA__5fRBROLLBACK;
	jint	XA__5fRBTIMEOUT;
	jint	XA__5fRBTRANSIENT;
	jint	XA__5fRDONLY;
	jint	XA__5fRETRY;
};
extern _jc_javax_transaction_xa_XAException$fields_struct _jc_javax_transaction_xa_XAException$class_fields;

// Constructors
extern void _jc_javax_transaction_xa_XAException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_transaction_xa_XAException$object *) _JC_JCNI_ATTR;
extern void _jc_javax_transaction_xa_XAException$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_transaction_xa_XAException$object *, jint) _JC_JCNI_ATTR;
extern void _jc_javax_transaction_xa_XAException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_transaction_xa_XAException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_transaction_xa_XAException$vmethods {
};

// Vtable
struct _jc_javax_transaction_xa_XAException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_transaction_xa_XAException$vmethods	javax_transaction_xa_XAException;
};

// Vtype
struct _jc_javax_transaction_xa_XAException$vtype {
	_jc_type			type;
	_jc_javax_transaction_xa_XAException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_transaction_xa_XAException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_transaction_xa_XAException$refs {
    _jc_javax_transaction_xa_XAException$sub_refs	javax_transaction_xa_XAException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_transaction_xa_XAException$sub_nonrefs {
	jint	errorCode;
};

// Non-reference instance fields (object)
struct _jc_javax_transaction_xa_XAException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_transaction_xa_XAException$sub_nonrefs	javax_transaction_xa_XAException;
};

// Object instance structure
struct _jc_javax_transaction_xa_XAException$object {
	_jc_javax_transaction_xa_XAException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_transaction_xa_XAException$vtype	*vtype;
	_jc_javax_transaction_xa_XAException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_transaction_xa_XAException$vtype _jc_javax_transaction_xa_XAException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_transaction_xa_XAException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_transaction_xa_XAException$class_object;

#endif	/* _JC_javax_transaction_xa_XAException_H_ */
